package app

import (
	"github.com/spf13/viper"
	"kumoly.io/kumoly/app/attribute"
	"kumoly.io/kumoly/app/auth"
	"kumoly.io/kumoly/app/control"
	"kumoly.io/kumoly/app/email"
	"kumoly.io/kumoly/app/history"
	"kumoly.io/kumoly/app/server"
	"kumoly.io/kumoly/app/store"
	"kumoly.io/kumoly/app/system"
	"kumoly.io/kumoly/app/task"
)

func Default() *system.System {
	store.Setup()
	sys := system.New()
	server := server.New(viper.GetString("name"))

	if err := attribute.Init(); err != nil {
		panic(err)
	}

	auth.Setup()
	auth.SetDB(store.DB)

	sys.Inject(auth.Injector(server.API))
	sys.Append(server, auth.New(server),
		&task.Service{},
		&history.Service{},
		&email.Service{},
		&control.Service{},
	)
	return sys
}
